@@ -95,7 +95,7 @@ class server:
         client.close()
         return check
     def regions():
-        return "SMTP regions: us, uk, de, ua, ru, tr"
+        return "SMTP regions: gmail.com, outlook.com, yandex.com, mail.ru"
     def debug(type:str):
         global debug
         if type == "on":
